@@ -62,8 +62,3 @@ TEST_F(DateTimeTest, TestToTimeT) {
 
 
 }  // end namespace kmlbase
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
