@@ -441,8 +441,3 @@ TEST_F(UriParserTest, TestFilenameToUri) {
 }
 
 }  // end namespace kmlbase
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
