@@ -148,9 +148,11 @@ TEST(Vec3Test, TestAssign2d) {
   ASSERT_EQ(0, copy2d.get_altitude());
 }
 
-}  // end namespace kmlbase
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
+TEST(Vec3Test, TestHeadingPitchRoll) {
+  Vec3 vec3(0.1, 1.2, 2.3);
+  ASSERT_EQ(0.1, vec3.get_heading());
+  ASSERT_EQ(1.2, vec3.get_pitch());
+  ASSERT_EQ(2.3, vec3.get_roll());
 }
+
+}  // end namespace kmlbase
