@@ -25,10 +25,14 @@
 
 // This file contains the implementation of the ZipFile class.
 
+#include <exception>
 #include "kml/base/zip_file.h"
 #include "kml/base/file.h"
-#include "minizip/unzip.h"
-#include "minizip/zip.h"
+
+#include "kml/base/contrib/minizip/unzip.h"
+#include "kml/base/contrib/minizip/iomem_simple.h"
+
+#include <minizip/zip.h>
 
 namespace kmlbase {
 
@@ -90,7 +94,7 @@ ZipFile::ZipFile(const string& data)
   if (voidpf mem_stream = mem_simple_create_file(
       &api, const_cast<void*>(static_cast<const void*>(data.data())),
       data.size())) {
-    unzFile zfile = unzAttach(mem_stream, &api);
+    unzFile zfile = libkml_unzAttach(mem_stream, &api);
     if (zfile) {
       unz_file_info finfo;
       do {
@@ -177,7 +181,7 @@ bool ZipFile::GetEntry(const string& path_in_zip,
   if (!mem_stream) {
     return false;
   }
-  unzFile unzfile = unzAttach(mem_stream, &api);
+  unzFile unzfile = libkml_unzAttach(mem_stream, &api);
   if (!unzfile) {
     return false;
   }
