@@ -351,8 +351,3 @@ TEST_F(ZipFileTest, TestMinizipOverflow) {
 }
 
 }  // end namespace kmlbase
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
