@@ -468,8 +468,3 @@ TEST(ConvenienceTest, TestSimplifyCoordinates) {
 }
 
 }  // end namespace kmlconvenience
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
