@@ -154,8 +154,3 @@ TEST_F(CsvFileTest, TestParseCsvFile) {
 }
 
 }  // namespace kmlconvenience
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
