@@ -121,8 +121,3 @@ TEST_F(ElementCounterTest, TestEachComplex) {
 }
 
 }  // namespace kmlconvenience
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
