@@ -224,9 +224,3 @@ TEST(HttpClientTest, FetchUrl) {
 }
 
 }  // end namespace kmlconvenience
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
-
