@@ -80,8 +80,3 @@ TEST_F(ColorStyleTest, TestSetGetHasClear) {
 }
 
 }  // end namespace kmldom
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
