@@ -69,6 +69,7 @@ FeaturePtr Container::DeleteFeatureById(const string& id) {
   for (; iter != feature_array_.end(); ++iter) {
     FeaturePtr feature = *iter;
     if (feature->has_id() && id == feature->get_id()) {
+  // TODO: if Container is in a KmlFile remove Feature from object map
       feature_array_.erase(iter);
       return feature;
     }
@@ -76,6 +77,10 @@ FeaturePtr Container::DeleteFeatureById(const string& id) {
   return NULL;
 }
 
+FeaturePtr Container::DeleteFeatureAt(size_t i) {
+  return Element::DeleteFromArrayAt(&feature_array_, i);
+}
+
 void Container::AcceptChildren(VisitorDriver* driver) {
   Feature::AcceptChildren(driver);
   Element::AcceptRepeated<FeaturePtr>(&feature_array_, driver);
