@@ -59,6 +59,10 @@ class Document : public Container {
     return schema_array_[index];
   }
 
+  SchemaPtr DeleteSchemaAt(size_t index) {
+    return Element::DeleteFromArrayAt(&schema_array_, index);
+  }
+
   // <Style> and <StyleMap>
   void add_styleselector(const StyleSelectorPtr& styleselector) {
     AddComplexChild(styleselector, &styleselector_array_);
@@ -72,6 +76,10 @@ class Document : public Container {
     return styleselector_array_[index];
   }
 
+  StyleSelectorPtr DeleteStyleSelectorAt(size_t index) {
+    return Element::DeleteFromArrayAt(&styleselector_array_, index);
+  }
+
   // Note: If Document contains a StyleSelector, it is appended to Document's
   // array of StyleSelectors and is NOT handed up to Feature. The current
   // KML Spec/XSD is incorrect in that it gives any Feature this array
