@@ -128,8 +128,3 @@ TEST_F(GxTimeStampTest, TestSetGetHasClear) {
 }
 
 }  // end namespace kmldom
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
