@@ -1,9 +1,9 @@
 // Copyright 2008, Google Inc. All rights reserved.
 //
-// Redistribution and use in source and binary forms, with or without 
+// Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
 //
-//  1. Redistributions of source code must retain the above copyright notice, 
+//  1. Redistributions of source code must retain the above copyright notice,
 //     this list of conditions and the following disclaimer.
 //  2. Redistributions in binary form must reproduce the above copyright notice,
 //     this list of conditions and the following disclaimer in the documentation
@@ -13,14 +13,14 @@
 //     specific prior written permission.
 //
 // THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
+// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 // MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
-// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
+// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 // SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 // PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 // OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
+// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 // ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // This file contains the KML 2.2 element names as found in the KML 2.2 XSD.
@@ -250,20 +250,32 @@ static XsdElement kKml22Elements[] = {
   { "gx:AnimatedUpdate", XSD_COMPLEX_TYPE },
   { "gx:FlyTo", XSD_COMPLEX_TYPE },
   { "gx:LatLonQuad", XSD_COMPLEX_TYPE },
+  { "gx:MultiTrack", XSD_COMPLEX_TYPE },
   { "gx:Playlist", XSD_COMPLEX_TYPE },
+  { "gx:SimpleArrayData", XSD_COMPLEX_TYPE },
+  { "gx:SimpleArrayField", XSD_COMPLEX_TYPE },
   { "gx:SoundCue", XSD_COMPLEX_TYPE },
   { "gx:TimeSpan", XSD_COMPLEX_TYPE },
   { "gx:TimeStamp", XSD_COMPLEX_TYPE },
   { "gx:Tour", XSD_COMPLEX_TYPE },
   { "gx:TourControl", XSD_COMPLEX_TYPE },
+  { "gx:Track", XSD_COMPLEX_TYPE },
   { "gx:Wait", XSD_COMPLEX_TYPE },
 
   // Google extension simple elements
   { "gx:altitudeMode", XSD_SIMPLE_TYPE },
+  { "gx:angles", XSD_SIMPLE_TYPE },
   { "gx:balloonVisibility", XSD_SIMPLE_TYPE },
+  { "gx:coord", XSD_SIMPLE_TYPE },
   { "gx:duration", XSD_SIMPLE_TYPE },
   { "gx:flyToMode", XSD_SIMPLE_TYPE },
+  { "gx:h", XSD_SIMPLE_TYPE },
+  { "gx:interpolate", XSD_SIMPLE_TYPE },
   { "gx:playMode", XSD_SIMPLE_TYPE },
+  { "gx:value", XSD_SIMPLE_TYPE },
+  { "gx:w", XSD_SIMPLE_TYPE },
+  { "gx:x", XSD_SIMPLE_TYPE },
+  { "gx:y", XSD_SIMPLE_TYPE },
 
   { "</Unknown>", XSD_UNKNOWN }  // Mark the end appropriately.
 };
