@@ -1,9 +1,9 @@
 // Copyright 2008, Google Inc. All rights reserved.
 //
-// Redistribution and use in source and binary forms, with or without 
+// Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
 //
-//  1. Redistributions of source code must retain the above copyright notice, 
+//  1. Redistributions of source code must retain the above copyright notice,
 //     this list of conditions and the following disclaimer.
 //  2. Redistributions in binary form must reproduce the above copyright notice,
 //     this list of conditions and the following disclaimer in the documentation
@@ -13,14 +13,14 @@
 //     specific prior written permission.
 //
 // THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
+// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 // MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
-// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
+// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 // SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 // PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 // OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
+// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 // ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #ifndef KML_DOM_KML_FACTORY_H__
@@ -39,6 +39,7 @@ class KmlFactory {
 
   // Factory functions used by the parser to create any KML element.
   ElementPtr CreateElementById(KmlDomType id) const;
+  ElementPtr CreateElementFromName(const string& element_name) const;
   Field* CreateFieldById(KmlDomType type_id) const;
 
   // Factory functions to create all KML complex elements.
@@ -125,12 +126,16 @@ class KmlFactory {
   GxAnimatedUpdate* CreateGxAnimatedUpdate() const;
   GxFlyTo* CreateGxFlyTo() const;
   GxLatLonQuad* CreateGxLatLonQuad() const;
+  GxMultiTrack* CreateGxMultiTrack() const;
   GxPlaylist* CreateGxPlaylist() const;
+  GxSimpleArrayData* CreateGxSimpleArrayData() const;
+  GxSimpleArrayField* CreateGxSimpleArrayField() const;
   GxSoundCue* CreateGxSoundCue() const;
   GxTimeSpan* CreateGxTimeSpan() const;
   GxTimeStamp* CreateGxTimeStamp() const;
   GxTour* CreateGxTour() const;
   GxTourControl* CreateGxTourControl() const;
+  GxTrack* CreateGxTrack() const;
   GxWait* CreateGxWait() const;
 
  private:
