@@ -1,9 +1,9 @@
 // Copyright 2008, Google Inc. All rights reserved.
 //
-// Redistribution and use in source and binary forms, with or without 
+// Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
 //
-//  1. Redistributions of source code must retain the above copyright notice, 
+//  1. Redistributions of source code must retain the above copyright notice,
 //     this list of conditions and the following disclaimer.
 //  2. Redistributions in binary form must reproduce the above copyright notice,
 //     this list of conditions and the following disclaimer in the documentation
@@ -13,14 +13,14 @@
 //     specific prior written permission.
 //
 // THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
+// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 // MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
-// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
+// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 // SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 // PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 // OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
+// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 // ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // This file contains the declaration of the public Parse and Serialize API
@@ -29,6 +29,7 @@
 #ifndef KML_DOM_KML_FUNCS_H__
 #define KML_DOM_KML_FUNCS_H__
 
+#include <ostream>
 #include "kml/dom/element.h"
 #include "kml/dom/kml_ptr.h"
 
@@ -62,6 +63,17 @@ string SerializePretty(const ElementPtr& root);
 // and no newlines.
 string SerializeRaw(const ElementPtr& root);
 
+// This function is the public API for emitting the XML of an element
+// hierarchy.  The comments for SerializePretty() vs SerializeRaw() describe
+// the behavior of the "pretty" flag.  If root or xml are null this method
+// does nothing and immediately returns.
+void SerializeToOstream(const ElementPtr& root, bool pretty, std::ostream* xml);
+
+// This function is the public API for returning the element's tag name, for
+// example "Placemark" for <Placemark> and "NetworkLink" for <NetworkLink>.
+// If element is NULL or otherwise invalid an empty string is returned.
+string GetElementName(const ElementPtr& element);
+
 }  // end namespace kmldom
 
 #endif  // KML_DOM_KML_FUNCS_H__
