@@ -369,8 +369,3 @@ TEST_F(RegionTest, TestSerialize) {
 }
 
 }  // end namespace kmldom
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
