@@ -238,8 +238,3 @@ TEST_F(LinkSnippetTest, TestSerializeCdata) {
 }
 
 }  // end namespace kmldom
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
