@@ -146,8 +146,3 @@ TEST_F(TimeStampTest, TestSetGetHasClear) {
 }
 
 }  // end namespace kmldom
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
