@@ -1,9 +1,9 @@
-// Copyright 2008, Google Inc. All rights reserved.
+﻿// Copyright 2008, Google Inc. All rights reserved.
 //
-// Redistribution and use in source and binary forms, with or without 
+// Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
 //
-//  1. Redistributions of source code must retain the above copyright notice, 
+//  1. Redistributions of source code must retain the above copyright notice,
 //     this list of conditions and the following disclaimer.
 //  2. Redistributions in binary form must reproduce the above copyright notice,
 //     this list of conditions and the following disclaimer in the documentation
@@ -13,19 +13,18 @@
 //     specific prior written permission.
 //
 // THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
+// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 // MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
-// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
+// EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 // SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 // PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 // OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
+// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 // ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // This file implements the internal Xsd class specifically for KML 2.2.
 
-#include <string>
 #include "kml/dom/xsd.h"
 #include "kml/dom/kml22.h"
 #include "kml/dom/kml22.cc"
@@ -47,7 +46,7 @@ Xsd::Xsd() {
   }
 }
 
-int Xsd::ElementId(const std::string& element_name) const {
+int Xsd::ElementId(const string& element_name) const {
   tag_id_map_t::const_iterator iter = tag_to_id.find(element_name);
   if (iter == tag_to_id.end()) {
     return Type_Unknown;
@@ -59,9 +58,9 @@ static bool is_valid(int id) {
   return id > Type_Unknown && id < Type_Invalid;
 }
 
-std::string Xsd::ElementName(int id) const {
+string Xsd::ElementName(int id) const {
   if (!is_valid(id)) {
-    return std::string();
+    return string();
   }
   // This is the other side of the wart found in KmlHandler::StartElement.
   // TODO: factor this and kKml22 out of Xsd.
@@ -80,17 +79,16 @@ XsdType Xsd::ElementType(int id) const {
   return element.xsd_type_;
 }
 
-int Xsd::EnumId(int type_id, std::string enum_value) const {
-  const int size = sizeof(kKml22Enums)/sizeof(XsdSimpleTypeEnum);
-  for (int i = 0; i < size; ++i) {
-    XsdSimpleTypeEnum* simple = kKml22Enums + i;
-    if (simple->type_id == type_id) {
-      for (const char** enum_value_item = simple->enum_value_list;
+int Xsd::EnumId(int type_id, string enum_value) const {
+const int size = sizeof(kKml22Enums)/sizeof(XsdSimpleTypeEnum);
+  for (int i = 0; i < size ; ++i) {
+    if (kKml22Enums[i].type_id == type_id) {
+      for (const char** enum_value_item = kKml22Enums[i].enum_value_list;
            *enum_value_item;
            ++enum_value_item) {
         if (*enum_value_item == enum_value) {
           // enum id is simple offset into enum_value_list;
-          return static_cast<int>(enum_value_item - simple->enum_value_list);
+          return static_cast<int>(enum_value_item - kKml22Enums[i].enum_value_list);
         }
       }
     }
@@ -102,16 +100,18 @@ int Xsd::EnumId(int type_id, std::string enum_value) const {
   return -1;
 }
 
-std::string Xsd::EnumValue(int type_id, int enum_id) const {
+string Xsd::EnumValue(int type_id, int enum_id) const {
   if (enum_id < 0) {
-    return std::string();
+    return string();
   }
-  for (XsdSimpleTypeEnum* simple = kKml22Enums; simple; ++simple) {
-    if (simple->type_id == type_id) {
-      return simple->enum_value_list[enum_id];
+const int size = sizeof(kKml22Enums)/sizeof(XsdSimpleTypeEnum);
+
+  for (int i = 0; i < size; ++i) {
+    if (kKml22Enums[i].type_id == type_id) {
+      return kKml22Enums[i].enum_value_list[enum_id];
     }
   }
-  return std::string();
+  return string();
 }
 
 
