@@ -107,8 +107,3 @@ TEST_F(GetLinksTest, TestGetRelativeLinks) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
