@@ -473,8 +473,3 @@ TEST_F(KmzTest, TestMaxUnCompressedSizeExceeded) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
