@@ -215,8 +215,3 @@ TEST_F(LinkUtilTest, TestFetchIcon) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
