@@ -218,8 +218,3 @@ TEST_F(StyleInlinerTest, TestFiles) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
