@@ -360,8 +360,3 @@ TEST_F(StyleMergerTest, TestNestingDepthDetection) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
