@@ -379,8 +379,3 @@ TEST_F(StyleResolverTest, BasicCreateResolvedStyleSelectorTest) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
