@@ -427,8 +427,3 @@ TEST(UpdateTest, TestProcessUpdateWithIdMapBasic) {
 }
 
 }  // end namespace kmlengine
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
