@@ -305,8 +305,3 @@ TEST_F(RegionatorUtilTest, TestCreateAlignedAbstractLatLonBox) {
 }
 
 }  // end namespace kmlregionator
-
-int main(int argc, char** argv) {
-  testing::InitGoogleTest(&argc, argv);
-  return RUN_ALL_TESTS();
-}
